==> haskell-setenv-0.1.1.3-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 setenv
version:              0.1.1.3
visibility:           public
id:                   setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY
key:                  setenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY
license:              MIT
copyright:            (c) 2012-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables

    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.

category:             System
abi:                  9441c3766a69b394aae4691dc4222911
exposed:              True
exposed-modules:      System.SetEnv
import-dirs:          /usr/lib/ghc-9.2.8/site-local/setenv-0.1.1.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-setenv
hs-libraries:         HSsetenv-0.1.1.3-3TgCzb5FKNIC6AFHCaPUY
depends:              base-4.16.4.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html:         /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-setenv-0.1.1.3-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-setenv.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 setenv
version:              0.1.1.3
visibility:           public
id:                   setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb
key:                  setenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb
license:              MIT
copyright:            (c) 2012-2015 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A cross-platform library for setting environment variables
description:
    A cross-platform library for setting environment variables

    Note: Since @base- 4.7.0.0@ the functions @setEnv@ and
    @unsetEnv@ are provided by @System.Environment@.
    @System.SetEnv@ merily re-exports those functions when built
    with @base >= 4.7@.

category:             System
abi:                  1f20384488805acd0726a0371cd9f83f
exposed:              True
exposed-modules:      System.SetEnv
import-dirs:          /usr/lib/ghc-9.4.8/site-local/setenv-0.1.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/setenv-0.1.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/setenv-0.1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-setenv
hs-libraries:         HSsetenv-0.1.1.3-4A8zWxAPPDXC38ifNLvqMb
depends:              base-4.17.2.1 unix-2.7.3
haddock-interfaces:   /usr/share/doc/haskell-setenv/html/setenv.haddock
haddock-html:         /usr/share/doc/haskell-setenv/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
